# encoding: utf-8
# frozen_string_literal: true
module TTWatcher
module Sites
module InternetConnection
  # TODO REFACTOR
  class Url # no-doc

    ##
    # Creates new Url instance.
    #
    # @param [String] url
    #   An url in any form.
    #
    # @param [Hash] params
    # @option params [Symbol] :force_scheme
    # @option params [Hash]   :query_params
    # @option params [String] :encoding
    #
    # @return [InternetConnection::Url]

    def initialize(url, **params)
      self.class.include Scheme

      @url      = url
      @query    = params[:query_params] || {}
      @encoding = params[:encoding]     || 'utf-8'

      set_scheme params[:force_scheme]
      encode_url
    end

    private

    attr_reader :encoding # no-doc
    attr_reader :url # no-doc

    ##
    # return +query+ with correct encoding

    def query_normalization
      uri =  Addressable::URI.parse url
      tmp_q = (uri.query_values || {}).merge(@query)

      return tmp_q if tmp_q.empty? && tmp_q.values.all? { |v| v.encode == @encoding }

      tmp_q.each_key do |k|
        tmp_q[k] = tmp_q[k].encode(encoding, invalid: :replace,
                                             undef: :replace)
      end

      return tmp_q
    end

    ##
    # Normalization. String to rfc-standard uri

    def encode_url
      uri = Addressable::URI.parse url
      uri.query_values = query_normalization
      @url.replace uri.normalize.to_s.force_encoding(@encoding)
    end
  end # class Url
end # module InternetConnection
end # module Sites
end # module TTWatcher
