# encoding: utf-8
# frozen_string_literal: true
module TTWatcher
module Parsers
  class Base # no-doc

    # @param [String] page
    #   Url to initial page for parsing.
    #
    # @return [TorrentList, NilClass]
    #   TorrentList instance with torrents.
    #   When parser crashed due to unknown reason it returns +nil+.

    def parse(page)
      raise NotImplementedError, "Abstract method called!"
    end

    # @return [Site]

    attr_reader :assigned_site

    # @return [Hash]

    attr_reader :settings

    ##
    # Creates Parser instance.
    #
    # @param [Site] site
    #
    # @return [Base]

    def initialize(site)
      @assigned_site = site
      @settings = S[site.name][:parser_settings] || {}
    end
  end # class Base
end # module Parsers
end # module TTWatcher
