# encoding: utf-8
# frozen_string_literal: true
module TTWatcher
module Sites
  class TorrentSite < Site # no-doc

    # @param [String] name
    #
    # @return [TrueClass, FalseClass]
    #   Returns +false+ when +name+ too short or not exists.

    def self.search_request_valid?(name)
      name && name.length >= 3
    end

    ##
    # Searches torrents.
    #
    # @param [String] name
    #   Torrent name.
    #
    # @return [TorrentList, NilClass]

    def find_torrent(name, request_params = {})
      return nil unless self.class.search_request_valid? name

      html_body = download_page search_url(name), request_params
      torrents = parser.parse html_body

      return torrents
    end

    private

    ##
    # Url for torrent searching.
    #   see Sites#search_url for an example.
    #
    # @param [String] name
    #   Used to extend url with +name+ when it need.
    #   For an example check Rutor#search_url

    def search_url(name=nil)
      raise NotImplementedError, "Abstract method called!"
    end

    ##
    # Returns a parser associated with Site instance throw class names.
    #
    # @return [Parsers::Base]

    def parser
      @parser ||=
        begin
          class_name = self.class.name.split('::').last
          parser = TTWatcher::Parsers.const_get class_name
          parser.new self
        end
    rescue NameError => exception
      notificate_about_parser_crash! exception

      return nil
    end

    def notificate_about_parser_crash!(exception)
      Logger.with_backtrace "Parser #{self} crashed with message: *** #{exception.message} ***"
    end
  end # class TorrentSite
end # module Sites
end # module TTWatcher
