# encoding: utf-8
# frozen_string_literal: true
module TTWatcher
  class Torrent

    # @return [String]
    #   Returns torrent name.

    attr_reader :name

    # @return [String]
    #   Returns torrent description.

    attr_reader :description

    # @return [String]
    #   Returns url to an page with additional info about torrent.

    attr_reader :url

    # @return [String]
    #   Returns torrent size.

    attr_reader :size

    # @return [String]
    #   Returns torrent creator.

    attr_reader :author

    # @return [String]
    #   Returns leeches count.

    attr_reader :leeches

    # @return [String]
    #   Returns seeders count.

    attr_reader :seeders

    # @return [String]
    #   Returns date (as string) when torrent was added.

    attr_reader :added_date

    # @return [String]
    #   Returns magnet url to the torrent.

    attr_reader :magnet_url

    # @return [String]
    #   Returns direct url for torrent download.

    attr_reader :download_url

    # @return [Symbol]
    #   Returns tracker for the torrent.

    attr_reader :tracker

    ##
    # Creates new Torrent instance.
    #
    # @param [Hash] params
    # @option params [String] :name
    # @option params [String] :description
    # @option params [String] :url.
    # @option params [Symbol] :tracker
    # @option params [String] :author
    # @option params [String] :added_date
    # @option params [Integer] :seeders
    # @option params [Integer] :leeches
    # @option params [String] :size
    # @option params [String] :magnet_url
    # @option params [String] :download_url
    #
    # @return [Torrent]

    def initialize(params = {})
      %i(name description url tracker author added_date seeders
         leeches size magnet_url download_url).each do |word|

        instance_variable_set "@#{word}", params[word]
      end
    end
  end # class Torrent
end # module TTWatcher
