# encoding: utf-8
# frozen_string_literal: true
module TTWatcher
  class TorrentList
    include Enumerable

    ##
    # Pushes new torrents into +TorrentList+.
    #
    # @param [Torrent, TorrentList] other
    #
    # @exception UnexpectedClass
    #   Raised when +other+ param class is not +Torrent+ or +TorrentList+
    #
    # @return [TorrentList<Torrent>]

    def push(other)
      case other
      when Torrent
        @torrents.push other
      when TorrentList
        @torrents += other.to_a
      else
        raise UnexpectedClass, other
      end

      return self
    end
    alias :<< :push
    alias :+  :push

    ##
    # Creates new TorrentList instance.
    #
    # @return [TorrentList]

    def initialize
      @torrents = []
    end

    def each(&block) # for Enumerable mixin
      @torrents.each { |obj| block.call obj }
    end

    ##
    # See TorrentList#push description.

    class UnexpectedClass < TTWError
      def initialize(obj); super "Object #{obj} cannot being pushed into TorrentList, since it's '#{obj.class}' class when only TorrentList/Torrent instances can be pushed"; end end
  end # class TorrentList
end # module TTWatcher
